﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using Infragistics.Controls.Layouts;
using Infragistics.Controls.Layouts.Primitives;
using Infragistics.Windows;

namespace XamTileManagerTests
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Initialize();
            PopulateData();
        }

        void pres_Loaded(object sender, RoutedEventArgs e)
        {
            var presenter = (sender as TileHeaderPresenter);
            var xamTileManager = Utilities.GetAncestorFromType(presenter, typeof(XamTileManager), false) as XamTileManager;
            if (xamTileManager != null && xamTileManager.Name == "EmpGroupsTileManager")
            {
                var tileHeaderPresenter = sender as TileHeaderPresenter;
                if (tileHeaderPresenter != null) 
                    tileHeaderPresenter.Style = null;
                var headerPresenter = sender as TileHeaderPresenter;
                if (headerPresenter != null)
                    headerPresenter.Style = this.FindResource("outerStyle") as Style;
            }
            else
            {
                var headerPresenter = sender as TileHeaderPresenter;
                if (headerPresenter != null) headerPresenter.Style = null;
                var tileHeaderPresenter = sender as TileHeaderPresenter;
                if (tileHeaderPresenter != null)
                    tileHeaderPresenter.Style = this.FindResource("innerStyle") as Style;
            }
        }

        private void Initialize()
        {
            EmpGroupsTileManager.InterTileSpacingX = 10;
            EmpGroupsTileManager.InterTileSpacingY = 10;
        }

        void Tile_PreviewMouseLeftButtonUp(object sender, MouseButtonEventArgs e)
        {
            if (e.Source is XamTile)
            {
                var xamTile = e.Source as XamTile;
                if (xamTile.Tag != null)
                {
                    MessageBox.Show("Selected employee is: " + ((Employee) xamTile.Tag).Name);
                }
            }
        }

        public List<Employee> GetEmployeeData()
        {
            var employeelist = new List<Employee>();
            var emp = new Employee {EmpNo = 1, Name = "ABC", Dept = "Finance"};
            employeelist.Add(emp);
            emp = new Employee { EmpNo = 2, Name = "DEF", Dept = "Admin" };
            employeelist.Add(emp);
            emp = new Employee { EmpNo = 3, Name = "GHI", Dept = "Sales" };
            employeelist.Add(emp);
            emp = new Employee { EmpNo = 4, Name = "JKL", Dept = "Finance" };
            employeelist.Add(emp);
            emp = new Employee { EmpNo = 5, Name = "MNO", Dept = "Admin" };
            employeelist.Add(emp);
            emp = new Employee { EmpNo = 6, Name = "PQR", Dept = "Sales" };
            employeelist.Add(emp);
            emp = new Employee { EmpNo = 7, Name = "STU", Dept = "Finance" };
            employeelist.Add(emp);
            emp = new Employee { EmpNo = 8, Name = "VWX", Dept = "Sales" };
            employeelist.Add(emp);
            return employeelist;
        }

        public void PopulateData()
        {
            try
            {
                List<Employee> empList = GetEmployeeData();

                Dictionary<string, List<Employee>> groupedEmpMap = (from Employee emp in empList group emp by emp.Dept).ToDictionary(x => x.Key, x => x.ToList());
                var groupTilesList = new List<XamTile>();

                foreach (string groupName in groupedEmpMap.Keys)
                {
                    var groupTile = new XamTile { Header = groupName, FontSize = 14.0, HorizontalAlignment = HorizontalAlignment.Stretch, VerticalAlignment = VerticalAlignment.Stretch };
                    AddInternalNodeTileToTileGroup(groupTile, groupedEmpMap[groupName]);
                    groupTile.Width = double.NaN;
                    groupTilesList.Add(groupTile);
                }
                EmpGroupsTileManager.ItemsSource = groupTilesList;
            }
            catch (Exception err)
            {
                MessageBox.Show(err.Message);
            }
        }

        private void AddInternalNodeTileToTileGroup(XamTile groupTile, List<Employee> empList)
        {
            try
            {
                var normalModeSettings = new NormalModeSettings { ExplicitLayoutTileSizeBehavior = ExplicitLayoutTileSizeBehavior.SynchronizeTileHeightsAcrossColumns };

                var empTilemanager = new XamTileManager
                {
                    InterTileSpacingX = 5,
                    InterTileSpacingY = 5,
                    HorizontalAlignment = HorizontalAlignment.Left,
                    NormalModeSettings = normalModeSettings,
                    TileCloseAction = TileCloseAction.RemoveItem,
                };
             
                empTilemanager.TileClosing += Tile_TileClosing;
                empTilemanager.PreviewMouseLeftButtonUp += Tile_PreviewMouseLeftButtonUp;

                foreach (Employee employee in empList)
                {
                    var nodeTile = new XamTile
                    {
                        MaximizeButtonVisibility = Visibility.Hidden,
                        IsMaximized = false,
                        ExpandButtonVisibility = Visibility.Hidden,
                        CloseButtonVisibility = Visibility.Visible,
                        CloseAction = TileCloseAction.RemoveItem,
                        Tag = employee,
                        ContentTemplate = this.Resources["EmpTileContentTemplate"] as DataTemplate,
                        DataContext = employee
                    };
                    empTilemanager.Items.Add(nodeTile);
                }
                groupTile.Content = empTilemanager;
            }
            catch (Exception err)
            {
                MessageBox.Show(err.Message);
            }
        }

        private void Tile_TileClosing(object sender, TileClosingEventArgs e)
        {
            var result = MessageBox.Show("Do you want to delete the emp record?", "Delete Confirmation",
                MessageBoxButton.YesNo, MessageBoxImage.Question);

            if (result != MessageBoxResult.Yes)
            {
                e.Cancel = true;
            }
        }
    }

    public class Employee
    {
        public int EmpNo { get; set; }
        public string Name { get; set; }
        public string Dept { get; set; }
    }
}
